@@ -113,6 +113,19 @@ where
             b"##FORMAT=<ID=DP,Number=1,Type=Integer,\
               Description=\"Expected sequencing depth, while considering mapping uncertainty\">",
         );
+        header.push_record(
+            b"##FORMAT=<ID=AF,Number=A,Type=Float,\
+              Description=\"Maximum a posteriori probability estimate of allele frequency\">",
+        );
+        header.push_record(
+            b"##FORMAT=<ID=SOBS,Number=A,Type=String,\
+              Description=\"Summary of simplified observations. Each entry is encoded as CB, with C being a count, \
+              B being the posterior odds for the alt allele. \
+              Posterior odds for alt allele of each fragment are given as extended Kass Raftery \
+              scores: N=none, E=equal, B=barely, P=positive, S=strong, V=very strong (lower case if \
+              probability for correct mapping of fragment is <95%). Note that we extend Kass Raftery scores with \
+              a term for equality between the evidence of the two alleles (E=equal).\">",
+        );
         header.push_record(
             b"##FORMAT=<ID=OBS,Number=A,Type=String,\
               Description=\"Summary of observations. Each entry is encoded as CBTSOPXI, with C being a count, \
@@ -128,19 +141,6 @@ where
               probability for correct mapping of fragment is <95%). Note that we extend Kass Raftery scores with \
               a term for equality between the evidence of the two alleles (E=equal).\">",
         );
-        header.push_record(
-            b"##FORMAT=<ID=SOBS,Number=A,Type=String,\
-              Description=\"Summary of simplified observations. Each entry is encoded as CB, with C being a count, \
-              B being the posterior odds for the alt allele. \
-              Posterior odds for alt allele of each fragment are given as extended Kass Raftery \
-              scores: N=none, E=equal, B=barely, P=positive, S=strong, V=very strong (lower case if \
-              probability for correct mapping of fragment is <95%). Note that we extend Kass Raftery scores with \
-              a term for equality between the evidence of the two alleles (E=equal).\">",
-        );
-        header.push_record(
-            b"##FORMAT=<ID=AF,Number=A,Type=Float,\
-              Description=\"Maximum a posteriori probability estimate of allele frequency\">",
-        );
         header.push_record(
             b"##FORMAT=<ID=SB,Number=A,Type=String,\
               Description=\"Strand bias estimate: + indicates that ALT allele is associated with \
@@ -184,6 +184,13 @@ where
               Probability for such homopolymer artifacts is captured by the ARTIFACT \
               event (PROB_ARTIFACT).\">",
         );
+        header.push_record(
+            b"##FORMAT=<ID=AFD,Number=A,Type=String,\
+              Description=\"Sampled posterior probability densities of allele frequencies in PHRED scale \
+              (the smaller the higher, with 0 being equal to an unscaled probability of 1). \
+              In the discrete case (no somatic mutation rate or continuous universe in the scenario), \
+              these can be seen as posterior probabilities. Note that densities can be greater than one.\">",
+        );
 
         Ok(header)
     }
@@ -249,7 +256,7 @@ where
         // data structures
         // For SNVs and MNVs we need a special model as here read orientation bias and read position bias needs to be considered.
         let mut models = HashMap::new();
-        let mut events = Vec::new();
+        let mut events = HashMap::new();
         let mut last_rids = HashMap::new();
 
         // process calls
@@ -305,6 +312,7 @@ where
             // process work item
             let contig = str::from_utf8(work_item.call.chrom()).unwrap();
             let _model;
+            let _events;
             let _last_rid;
 
             let model_mode = (
@@ -314,6 +322,7 @@ where
                 work_item.check_homopolymer_artifact_detection,
             );
             _model = models.entry(model_mode).or_insert_with(|| self.model());
+            _events = events.entry(model_mode).or_insert_with(Vec::new);
             {
                 let entry = last_rids.entry(model_mode).or_insert(None);
                 _last_rid = *entry;
@@ -324,7 +333,7 @@ where
                 work_item.rid,
                 _last_rid,
                 _model,
-                &mut events,
+                _events,
                 contig,
                 variant_type,
                 work_item.check_read_orientation_bias,
@@ -334,7 +343,7 @@ where
                 work_item.check_homopolymer_artifact_detection,
             )?;
 
-            self.call_record(&mut work_item, _model, &events);
+            self.call_record(&mut work_item, _model, &_events);
 
             work_item.call.write_final_record(&mut bcf_writer)?;
             progress_logger.update(1u64);
@@ -442,12 +451,8 @@ where
                     // METHOD: check for homopolymer artifacts if at least one pileup contains the corresponding information.
                     work_item.check_homopolymer_artifact_detection |= true;
                 }
+                Observation::adjust_prob_mapping(&mut pileup);
                 if is_snv_or_mnv {
-                    // METHOD: adjust MAPQ to get rid of stochastically inflated ones
-                    // This takes the arithmetic mean of all MAPQs in the pileup.
-                    // By that, we effectively diminish high MAPQs of reads that just achieve them
-                    // because of e.g. randomly better matching bases in themselves or their mates.
-                    Observation::adjust_prob_mapping(&mut pileup);
                     // METHOD: remove non-standard alignments. They might come from near
                     // SVs and can induce artifactual SNVs or MNVs. By removing them,
                     // we just conservatively reduce the coverage to those which are
@@ -484,8 +489,8 @@ where
         consider_softclip_bias: bool,
         consider_homopolymer_error: bool,
     ) -> Result<()> {
-        if !rid.map_or(false, |rid: u32| current_rid == rid) {
-            // rid is not the same as before, obtain event universe
+        if !rid.map_or(false, |rid: u32| current_rid == rid) || events.is_empty() {
+            // rid is not the same as before or the model mode has changed to something new, obtain event universe
             // clear old events
             events.clear();
 
@@ -667,11 +672,13 @@ where
                 // This ensures consistency between the events and the per sample MAPs.
                 continue;
             }
+            // This is the MAP estimate we want to report, build sample information with it.
             return data
                 .into_pileups()
                 .into_iter()
                 .zip(map_estimates.iter())
-                .map(|(pileup, estimate)| {
+                .enumerate()
+                .map(|(sample, (pileup, estimate))| {
                     let mut sample_builder = SampleInfoBuilder::default();
                     sample_builder.observations(pileup);
                     match estimate {
@@ -688,6 +695,44 @@ where
                                 .artifacts(Artifacts::none());
                         }
                     };
+
+                    // METHOD: Collect VAF dist for sample by looking at all alternative VAFs with the same VAFs for the other samples as the MAP.
+                    sample_builder.vaf_dist(if !estimate.is_artifact() {
+                        Some(
+                            model_instance
+                                .event_posteriors()
+                                .filter_map(|(estimate, prob)| {
+                                    let event = estimate.events().get(sample).unwrap();
+                                    let others_equal_map = || {
+                                        map_estimates.events().iter().all(
+                                            |(other_sample, map_event)| {
+                                                //dbg!((other_sample, sample, estimate.events().get(other_sample).unwrap(), map_event));
+                                                if other_sample != sample {
+                                                    // check if other event is the same as the map event
+                                                    let other_event = estimate
+                                                        .events()
+                                                        .get(other_sample)
+                                                        .unwrap();
+                                                    other_event == map_event
+                                                } else {
+                                                    // don't do that for our current sample
+                                                    true
+                                                }
+                                            },
+                                        )
+                                    };
+                                    if !event.is_artifact() && others_equal_map() {
+                                        Some((event.allele_freq, prob))
+                                    } else {
+                                        None
+                                    }
+                                })
+                                .collect(),
+                        )
+                    } else {
+                        None
+                    });
+
                     Some(sample_builder.build().unwrap())
                 })
                 .collect_vec();
