@@ -111,8 +111,7 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
             "SOFTCLIPPED",
             "ALT_INDEL_OPERATIONS",
             "PAIRED",
-            "PROB_WILDTYPE_HOMOPOLYMER_ERROR",
-            "PROB_ARTIFACT_HOMOPOLYMER_ERROR",
+            "PROB_HOMOPOLYMER_OBSERVABLE",
             "HOMOPOLYMER_INDEL_LEN",
         ] {
             header.push_record(
@@ -360,23 +359,51 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
         };
         let start = work_item.start as usize;
 
+        let ref_base = || {
+            self.reference_buffer
+                .seq(&work_item.chrom)?
+                .get(start)
+                .cloned()
+                .ok_or_else(|| -> anyhow::Error {
+                    errors::invalid_bcf_record(
+                        locus().contig(),
+                        locus().pos() as i64,
+                        "position larger than reference length",
+                    )
+                    .into()
+                })
+        };
+
         Ok(Some(match variant {
-            model::Variant::Snv(alt) => sample.extract_observations(&variants::types::Snv::new(
-                locus(),
-                self.reference_buffer.seq(&work_item.chrom)?[start],
-                *alt,
-                self.realigner.clone(),
-            ))?,
+            model::Variant::Snv(alt) => {
+                let locus = locus();
+                sample.extract_observations(&variants::types::Snv::new(
+                    locus,
+                    ref_base()?,
+                    *alt,
+                    self.realigner.clone(),
+                ))?
+            }
             model::Variant::Mnv(alt) => sample.extract_observations(&variants::types::Mnv::new(
                 locus(),
-                self.reference_buffer.seq(&work_item.chrom)?[start..start + alt.len()].to_owned(),
+                self.reference_buffer
+                    .seq(&work_item.chrom)?
+                    .get(start..start + alt.len())
+                    .ok_or_else(|| -> anyhow::Error {
+                        errors::invalid_bcf_record(
+                            locus().contig(),
+                            locus().pos() as i64,
+                            "MNV exceeds reference length",
+                        )
+                        .into()
+                    })?
+                    .to_owned(),
                 alt.to_owned(),
                 self.realigner.clone(),
             ))?,
-            model::Variant::None => sample.extract_observations(&variants::types::None::new(
-                locus(),
-                self.reference_buffer.seq(&work_item.chrom)?[start],
-            ))?,
+            model::Variant::None => {
+                sample.extract_observations(&variants::types::None::new(locus(), ref_base()?))?
+            }
             model::Variant::Deletion(l) => sample.extract_observations(
                 &variants::types::Deletion::new(interval(*l), self.realigner.clone())?,
             )?,
@@ -478,7 +505,7 @@ impl<R: realignment::Realigner + Clone + std::marker::Send + std::marker::Sync>
     }
 }
 
-pub(crate) static OBSERVATION_FORMAT_VERSION: &str = "10";
+pub(crate) static OBSERVATION_FORMAT_VERSION: &str = "11";
 
 pub(crate) struct Observations {
     pub(crate) observations: Vec<Observation<ReadPosition>>,
@@ -495,8 +522,12 @@ pub(crate) fn read_observations(record: &mut bcf::Record) -> Result<Observations
         if allow_missing && info.is_none() {
             return Ok(T::default());
         }
-        let raw_values = info.ok_or_else(|| errors::Error::InvalidBCFRecord {
-            msg: "No varlociraptor observations found in record.".to_owned(),
+        let raw_values = info.ok_or_else(|| {
+            errors::invalid_bcf_record(
+                record.contig(),
+                record.pos(),
+                "No varlociraptor observations found in record.",
+            )
         })?;
 
         // decode from i32 to u16 to u8
@@ -526,18 +557,16 @@ pub(crate) fn read_observations(record: &mut bcf::Record) -> Result<Observations
     let read_position: Vec<ReadPosition> = read_values(record, b"READ_POSITION", false)?;
     let softclipped: BitVec<u8> = read_values(record, b"SOFTCLIPPED", false)?;
     let paired: BitVec<u8> = read_values(record, b"PAIRED", false)?;
-    let prob_wildtype_homopolymer_error: Vec<MiniLogProb> =
-        read_values(record, b"PROB_WILDTYPE_HOMOPOLYMER_ERROR", true)?;
-    let prob_artifact_homopolymer_error: Vec<MiniLogProb> =
-        read_values(record, b"PROB_ARTIFACT_HOMOPOLYMER_ERROR", true)?;
-    let homopolymer_indel_len: Vec<i8> = read_values(record, b"HOMOPOLYMER_INDEL_LEN", true)?;
-
-    let is_homopolymer_indel = !prob_artifact_homopolymer_error.is_empty();
+    let prob_observable_at_homopolymer_artifact: Vec<Option<MiniLogProb>> =
+        read_values(record, b"PROB_HOMOPOLYMER_OBSERVABLE", true)?;
+    let homopolymer_indel_len: Vec<Option<i8>> =
+        read_values(record, b"HOMOPOLYMER_INDEL_LEN", true)?;
+    let is_homopolymer_indel = !prob_observable_at_homopolymer_artifact.is_empty();
 
     let obs = (0..prob_mapping.len())
         .map(|i| {
-            ObservationBuilder::default()
-                .name(None) // we do not pass the read names to the calling process
+            let mut obs = ObservationBuilder::default();
+            obs.name(None) // we do not pass the read names to the calling process
                 .prob_mapping_mismapping(prob_mapping[i].to_logprob())
                 .prob_alt(prob_alt[i].to_logprob())
                 .prob_ref(prob_ref[i].to_logprob())
@@ -549,24 +578,18 @@ pub(crate) fn read_observations(record: &mut bcf::Record) -> Result<Observations
                 .read_orientation(read_orientation[i])
                 .read_position(read_position[i])
                 .softclipped(softclipped[i as u64])
-                .prob_wildtype_homopolymer_error(if is_homopolymer_indel {
-                    Some(prob_wildtype_homopolymer_error[i].to_logprob())
-                } else {
-                    None
-                })
-                .prob_artifact_homopolymer_error(if is_homopolymer_indel {
-                    Some(prob_artifact_homopolymer_error[i].to_logprob())
-                } else {
-                    None
-                })
-                .homopolymer_indel_len(if is_homopolymer_indel {
-                    Some(homopolymer_indel_len[i])
-                } else {
-                    None
-                })
-                .paired(paired[i as u64])
-                .build()
-                .unwrap()
+                .paired(paired[i as u64]);
+
+            if is_homopolymer_indel {
+                obs.homopolymer_indel_len(homopolymer_indel_len[i])
+                    .prob_observable_at_homopolymer_artifact(
+                        prob_observable_at_homopolymer_artifact[i].map(|prob| prob.to_logprob()),
+                    );
+            } else {
+                obs.homopolymer_indel_len(None)
+                    .prob_observable_at_homopolymer_artifact(None);
+            }
+            obs.build().unwrap()
         })
         .collect_vec();
 
@@ -593,9 +616,9 @@ pub(crate) fn write_observations(
     let mut paired: BitVec<u8> = BitVec::with_capacity(observations.len() as u64);
     let mut read_position = Vec::with_capacity(observations.len());
     let mut prob_hit_base = vec();
-    let mut prob_wildtype_homopolymer_error = Vec::with_capacity(observations.len());
-    let mut prob_artifact_homopolymer_error = Vec::with_capacity(observations.len());
-    let mut homopolymer_indel_len: Vec<i8> = Vec::with_capacity(observations.len());
+    let mut prob_observable_at_homopolymer_artifact: Vec<Option<MiniLogProb>> =
+        Vec::with_capacity(observations.len());
+    let mut homopolymer_indel_len: Vec<Option<i8>> = Vec::with_capacity(observations.len());
 
     let encode_logprob = |prob: LogProb| utils::MiniLogProb::new(prob);
     for obs in observations {
@@ -612,15 +635,11 @@ pub(crate) fn write_observations(
         paired.push(obs.paired);
         read_position.push(obs.read_position);
 
-        if let Some(prob) = obs.prob_wildtype_homopolymer_error {
-            prob_wildtype_homopolymer_error.push(encode_logprob(prob));
-        }
-        if let Some(prob) = obs.prob_artifact_homopolymer_error {
-            prob_artifact_homopolymer_error.push(encode_logprob(prob));
-        }
-        if let Some(indel_len) = obs.homopolymer_indel_len {
-            homopolymer_indel_len.push(indel_len);
-        }
+        prob_observable_at_homopolymer_artifact.push(
+            obs.prob_observable_at_homopolymer_artifact
+                .map(|prob| encode_logprob(prob)),
+        );
+        homopolymer_indel_len.push(obs.homopolymer_indel_len);
     }
 
     fn push_values<T>(record: &mut bcf::Record, tag: &[u8], values: &T) -> Result<()>
@@ -660,16 +679,15 @@ pub(crate) fn write_observations(
     push_values(record, b"READ_POSITION", &read_position)?;
     push_values(record, b"PROB_HIT_BASE", &prob_hit_base)?;
 
-    if !prob_wildtype_homopolymer_error.is_empty() {
+    if prob_observable_at_homopolymer_artifact
+        .iter()
+        .any(|prob| prob.is_some())
+    {
+        // only record values if there is any homopolymer error observation
         push_values(
             record,
-            b"PROB_WILDTYPE_HOMOPOLYMER_ERROR",
-            &prob_wildtype_homopolymer_error,
-        )?;
-        push_values(
-            record,
-            b"PROB_ARTIFACT_HOMOPOLYMER_ERROR",
-            &prob_artifact_homopolymer_error,
+            b"PROB_HOMOPOLYMER_OBSERVABLE",
+            &prob_observable_at_homopolymer_artifact,
         )?;
         push_values(record, b"HOMOPOLYMER_INDEL_LEN", &homopolymer_indel_len)?;
     }
@@ -690,8 +708,7 @@ pub(crate) fn remove_observation_header_entries(header: &mut bcf::Header) {
     header.remove_info(b"PAIRED");
     header.remove_info(b"PROB_HIT_BASE");
     header.remove_info(b"READ_POSITION");
-    header.remove_info(b"PROB_WILDTYPE_HOMOPOLYMER_ERROR");
-    header.remove_info(b"PROB_ARTIFACT_HOMOPOLYMER_ERROR");
+    header.remove_info(b"PROB_HOMOPOLYMER_OBSERVABLE");
     header.remove_info(b"HOMOPOLYMER_INDEL_LEN");
 }
 
