@@ -26,7 +26,7 @@ use crate::errors::{self, Error};
 use crate::estimation::alignment_properties::AlignmentProperties;
 use crate::utils;
 use crate::utils::homopolymers::HomopolymerErrorModel;
-use crate::utils::PROB_095;
+use crate::utils::{PROB_05, PROB_09, PROB_095};
 use crate::variants::sample;
 use crate::variants::types::Variant;
 
@@ -201,10 +201,9 @@ where
     pub(crate) paired: bool,
     /// Read position of the variant in the read (for SNV and MNV)
     pub(crate) read_position: P,
-    /// Probability for harboring homopolymer error from artifact homopolymer error model
-    pub(crate) prob_artifact_homopolymer_error: Option<LogProb>,
-    /// Probability for harboring homopolymer error from wildtype homopolymer error model
-    pub(crate) prob_wildtype_homopolymer_error: Option<LogProb>,
+    /// Probability to make this observation at a homopolymer artifact
+    pub(crate) prob_observable_at_homopolymer_artifact: Option<LogProb>,
+    /// Homopolymer indel length (None if there is no homopolymer indel compared to reference)
     pub(crate) homopolymer_indel_len: Option<i8>,
 }
 
@@ -250,8 +249,7 @@ impl Observation<Option<u32>> {
                     ReadPosition::Some
                 }
             }),
-            prob_wildtype_homopolymer_error: self.prob_wildtype_homopolymer_error,
-            prob_artifact_homopolymer_error: self.prob_artifact_homopolymer_error,
+            prob_observable_at_homopolymer_artifact: self.prob_observable_at_homopolymer_artifact,
             homopolymer_indel_len: self.homopolymer_indel_len,
         }
     }
@@ -320,13 +318,30 @@ impl<P: Clone> Observation<P> {
 
     pub(crate) fn adjust_prob_mapping(pileup: &mut [Self]) {
         if !pileup.is_empty() {
-            let prob_sum = LogProb::ln_sum_exp(
+            // METHOD: adjust MAPQ to get rid of stochastically inflated ones
+            // This takes the arithmetic mean of all MAPQs in the pileup.
+            // By that, we effectively diminish high MAPQs of reads that just achieve them
+            // because of e.g. randomly better matching bases in themselves or their mates.
+            let mut prob_sum = LogProb::ln_sum_exp(
                 &pileup
                     .iter()
                     .map(|obs| obs.prob_mapping_orig())
                     .collect_vec(),
             );
-            let adjusted = LogProb(*prob_sum - (pileup.len() as f64).ln());
+
+            let calc_adjusted = |prob_sum: LogProb, n| LogProb(*prob_sum - (n as f64).ln());
+            let mut adjusted = calc_adjusted(prob_sum, pileup.len());
+
+            if pileup.len() < 20 {
+                // METHOD: for low depths, this method does not reliably work because it can be that by accident the
+                // low MAPQ reads are not in the pileup. In order to correct for this sampling issue,
+                // we add one pseudo low MAPQ observation. The higher the depth becomes, the less this observation
+                // plays a role.
+                prob_sum = prob_sum.ln_add_exp(adjusted + *PROB_09);
+
+                adjusted = calc_adjusted(prob_sum, pileup.len() + 1);
+            }
+
             for obs in pileup {
                 if adjusted < obs.prob_mapping_orig() {
                     obs.prob_mapping_adj = Some(adjusted);
@@ -403,17 +418,25 @@ where
                     .prob_hit_base(LogProb::ln_one() - LogProb((evidence.len() as f64).ln()));
 
                 if let Some(homopolymer_error_model) = homopolymer_error_model {
-                    obs.homopolymer_indel_len(Some(read_indel_len))
-                        .prob_wildtype_homopolymer_error(Some(
-                            homopolymer_error_model.prob_wildtype_homopolymer_error(read_indel_len),
-                        ))
-                        .prob_artifact_homopolymer_error(Some(
-                            homopolymer_error_model.prob_artifact_homopolymer_error(read_indel_len),
-                        ));
+                    let ref_indel_len =
+                        read_indel_len + homopolymer_error_model.variant_homopolymer_indel_len();
+                    if ref_indel_len == 0 {
+                        // no homopolymer indel in read compared to reference
+                        obs.homopolymer_indel_len(None)
+                            .prob_observable_at_homopolymer_artifact(None);
+                    } else {
+                        obs.homopolymer_indel_len(Some(read_indel_len))
+                            .prob_observable_at_homopolymer_artifact(if ref_indel_len == 0 {
+                                unreachable!("caught above");
+                            } else if ref_indel_len > 0 {
+                                Some(homopolymer_error_model.prob_homopolymer_insertion())
+                            } else {
+                                Some(homopolymer_error_model.prob_homopolymer_deletion())
+                            });
+                    }
                 } else {
                     obs.homopolymer_indel_len(None)
-                        .prob_wildtype_homopolymer_error(None)
-                        .prob_artifact_homopolymer_error(None);
+                        .prob_observable_at_homopolymer_artifact(None);
                 }
 
                 Some(obs.build().unwrap())
