@@ -38,7 +38,7 @@ pub(crate) trait RefBaseEmission {
 
     /// Reference area that is altered by the variant.
     /// Can return None if not applicable (default).
-    fn variant_ref_range(&self) -> Option<Range<usize>>;
+    fn variant_homopolymer_ref_range(&self) -> Option<Range<u64>>;
 
     fn shrink_to_hit(&mut self, hit: &EditDistanceHit) {
         self.set_ref_end(cmp::min(
@@ -49,6 +49,10 @@ pub(crate) trait RefBaseEmission {
     }
 }
 
+pub(crate) trait VariantEmission {
+    fn is_homopolymer_indel(&self) -> bool;
+}
+
 #[macro_export]
 macro_rules! default_ref_base_emission {
     () => {
@@ -229,7 +233,7 @@ impl<'a> RefBaseEmission for ReferenceEmissionParams<'a> {
         self.ref_seq[i + self.ref_offset]
     }
 
-    fn variant_ref_range(&self) -> Option<Range<usize>> {
+    fn variant_homopolymer_ref_range(&self) -> Option<Range<u64>> {
         None
     }
 
@@ -244,3 +248,9 @@ impl<'a> pairhmm::EmissionParameters for ReferenceEmissionParams<'a> {
         self.ref_end - self.ref_offset
     }
 }
+
+impl<'a> VariantEmission for ReferenceEmissionParams<'a> {
+    fn is_homopolymer_indel(&self) -> bool {
+        false
+    }
+}
