@@ -283,8 +283,7 @@ mod tests {
             .read_position(ReadPosition::Some)
             .strand(Strand::Both)
             .softclipped(false)
-            .prob_wildtype_homopolymer_error(None)
-            .prob_artifact_homopolymer_error(None)
+            .prob_observable_at_homopolymer_artifact(None)
             .homopolymer_indel_len(None)
             .paired(true)
             .prob_hit_base(LogProb::from(0.01f64.ln()))
