@@ -13,6 +13,8 @@ use rust_htslib::bam;
 use vec_map::VecMap;
 
 use crate::estimation::alignment_properties::AlignmentProperties;
+use crate::utils::homopolymers::HomopolymerErrorModel;
+use crate::utils::PROB_05;
 use crate::variants::evidence::observation::{
     Evidence, Observable, Observation, PairedEndEvidence, SingleEndEvidence, Strand,
 };
@@ -39,9 +41,7 @@ pub(crate) use snv::Snv;
 
 #[derive(Debug, CopyGetters, Getters, Builder)]
 pub(crate) struct AlleleSupport {
-    #[getset(get_copy = "pub")]
     prob_ref_allele: LogProb,
-    #[getset(get_copy = "pub")]
     prob_alt_allele: LogProb,
     #[getset(get_copy = "pub")]
     strand: Strand,
@@ -50,10 +50,30 @@ pub(crate) struct AlleleSupport {
     read_position: Option<u32>,
     #[builder(default)]
     #[getset(get_copy = "pub")]
-    has_alt_indel_operations: bool,
+    homopolymer_indel_len: Option<i8>,
 }
 
 impl AlleleSupport {
+    fn both_alleles_impossible(&self) -> bool {
+        *self.prob_ref_allele == f64::NEG_INFINITY && *self.prob_alt_allele == f64::NEG_INFINITY
+    }
+
+    pub(crate) fn prob_ref_allele(&self) -> LogProb {
+        if self.both_alleles_impossible() {
+            *PROB_05
+        } else {
+            self.prob_ref_allele
+        }
+    }
+
+    pub(crate) fn prob_alt_allele(&self) -> LogProb {
+        if self.both_alleles_impossible() {
+            *PROB_05
+        } else {
+            self.prob_alt_allele
+        }
+    }
+
     /// METHOD: This is an estimate of the allele likelihood at the true location in case
     /// the read is mismapped. The value has to be approximately in the range of prob_alt
     /// and prob_ref. Otherwise it could cause numerical problems, by dominating the
@@ -69,12 +89,18 @@ impl AlleleSupport {
 
         if self.strand == Strand::None {
             self.strand = other.strand;
-            self.has_alt_indel_operations = other.has_alt_indel_operations;
+            self.homopolymer_indel_len = other.homopolymer_indel_len;
         } else if other.strand != Strand::None {
             if self.strand != other.strand {
                 self.strand = Strand::Both;
             }
-            self.has_alt_indel_operations |= other.has_alt_indel_operations;
+            self.homopolymer_indel_len =
+                match (self.homopolymer_indel_len, other.homopolymer_indel_len) {
+                    (Some(indel_len), Some(_other_indel_len)) => Some(indel_len), // just keep one of them
+                    (Some(indel_len), None) => Some(indel_len),
+                    (None, Some(indel_len)) => Some(indel_len),
+                    (None, None) => None,
+                }
         }
 
         self
@@ -114,9 +140,13 @@ pub(crate) trait Variant {
         alignment_properties: &AlignmentProperties,
     ) -> LogProb;
 
-    /// Whether the variant shall report indel operations for the DivIndelBias calculation.
-    fn report_indel_operations(&self) -> bool {
-        false
+    /// Return the homopolymer indel len of the variant, if any.
+    fn homopolymer_indel_len(&self) -> Option<i8> {
+        None
+    }
+
+    fn is_homopolymer_indel(&self) -> bool {
+        self.homopolymer_indel_len().is_some()
     }
 }
 
@@ -138,6 +168,8 @@ where
         let locus = self.loci();
         buffer.fetch(locus, false)?;
 
+        let homopolymer_error_model = HomopolymerErrorModel::new(self, alignment_properties);
+
         let candidates: Vec<_> = buffer
             .iter()
             .filter_map(|record| {
@@ -163,7 +195,11 @@ where
         let mut observations = Vec::new();
         for evidence in candidates {
             if subsampler.keep() {
-                if let Some(obs) = self.evidence_to_observation(&evidence, alignment_properties)? {
+                if let Some(obs) = self.evidence_to_observation(
+                    &evidence,
+                    alignment_properties,
+                    &homopolymer_error_model,
+                )? {
                     observations.push(obs);
                 }
             }
@@ -206,6 +242,8 @@ where
         // in slightly different probabilities each time.
         let mut candidate_records = BTreeMap::new();
 
+        let homopolymer_error_model = HomopolymerErrorModel::new(self, alignment_properties);
+
         let mut fetches = buffer.build_fetches(true);
         for locus in self.loci().iter() {
             fetches.push(locus);
@@ -292,7 +330,11 @@ where
         let mut observations = Vec::new();
         for evidence in &candidates {
             if !subsample || subsampler.keep() {
-                if let Some(obs) = self.evidence_to_observation(evidence, alignment_properties)? {
+                if let Some(obs) = self.evidence_to_observation(
+                    evidence,
+                    alignment_properties,
+                    &homopolymer_error_model,
+                )? {
                     observations.push(obs);
                 }
             }
