@@ -19,6 +19,7 @@ use crate::reference;
 use crate::utils;
 use crate::variants::evidence::bases::prob_read_base;
 use crate::variants::evidence::observation::Strand;
+use crate::variants::evidence::realignment::pairhmm::VariantEmission;
 use crate::variants::evidence::realignment::pairhmm::{ReadEmission, RefBaseEmission};
 use crate::variants::evidence::realignment::{Realignable, Realigner};
 use crate::variants::types::{
@@ -185,8 +186,8 @@ impl<'a> RefBaseEmission for SnvEmissionParams<'a> {
         }
     }
 
-    fn variant_ref_range(&self) -> Option<Range<usize>> {
-        Some(self.alt_start..self.alt_start + 1)
+    fn variant_homopolymer_ref_range(&self) -> Option<Range<u64>> {
+        None
     }
 
     default_ref_base_emission!();
@@ -201,6 +202,12 @@ impl<'a> EmissionParameters for SnvEmissionParams<'a> {
     }
 }
 
+impl<'a> VariantEmission for SnvEmissionParams<'a> {
+    fn is_homopolymer_indel(&self) -> bool {
+        false
+    }
+}
+
 // #[cfg(test)]
 // mod tests {
 
